Coverage for /home/ken/src/shared/avendesora/avendesora/main.py: 0%

# Coverage for /home/ken/src/shared/avendesora/avendesora/main.py : 0%

## 22 statements 0 run 22 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 | #!/usr/bin/env python3 # Usage {{{1 """ Avendesora Collaborative Password Generator Generates passwords and pass phrases based on stored account information. Usage: avendesora [options] <command> [<args>...] Options: -h, --help Output basic usage information. Commands: {commands} Use 'avendesora help <command>' for information on a specific command. Use 'avendesora help' for list of available help topics. """ # License {{{1 # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU General Public License for more details. # # You should have received a copy of the GNU General Public License # along with this program. If not, see http://www.gnu.org/licenses/. # Imports {{{1 from .command import Command from .config import read_config, get_setting from .gpg import GnuPG, BufferedFile from inform import Inform, Error, fatal, output, terminate, debug, os_error from shlib import to_path from docopt import docopt import sys # Main {{{1 def main(): # read config file read_config() # read command line cmdline = docopt( __doc__.format(commands=Command.summarize()), options_first=True ) # start logging logfile = BufferedFile(get_setting('log_file'), True) with Inform(logfile=logfile, hanging_indent=False): try: Command.execute(cmdline['<command>'], cmdline['<args>']) except KeyboardInterrupt: output('Terminated by user.') except Error as err: err.terminate() except OSError as err: fatal(os_error(err)) terminate()